@@ -27,15 +27,15 @@ macro_rules! table_read {
     );
 }
 
-mod charset;
+mod char_set;
 mod encoding;
 mod header;
 mod index;
 mod operation;
 
-pub use self::charset::{Charset, Charset1, CharsetRange1};
+pub use self::char_set::{CharSet, CharSet1, CharSetRange1};
 pub use self::encoding::Encoding;
 pub use self::header::Header;
-pub use self::index::{Charstrings, Index, Names};
+pub use self::index::{CharStrings, Index, Names};
 pub use self::index::{Strings, Subroutines, TopDictionaries};
 pub use self::operation::{Operation, Operations, Operator};
