@@ -5,17 +5,23 @@ use std::io::{Cursor, Read, Seek};
 use Result;
 use tape::{Tape, Value, Walue};
 
+mod compound;
+mod primitive;
+
+pub use self::compound::*;
+pub use self::primitive::*;
+
 /// A font set.
 pub struct FontSet {
     pub header: Header,
     pub names: Vec<String>,
-    pub top_dictionaries: Vec<Operations>,
     pub strings: Strings,
-    pub global_subroutines: Subroutines,
     pub encodings: Vec<Encoding>,
-    pub charsets: Vec<Charset>,
-    pub charstrings: Vec<Charstrings>,
+    pub char_sets: Vec<CharSet>,
+    pub char_strings: Vec<CharStrings>,
+    pub top_dictionaries: Vec<Operations>,
     pub private_dictionaries: Vec<Operations>,
+    pub global_subroutines: Subroutines,
     pub local_subroutines: Vec<Subroutines>,
 }
 
@@ -57,8 +63,8 @@ impl Value for FontSet {
         let global_subroutines = try!(Subroutines::read(tape));
 
         let mut encodings = vec![];
-        let mut charsets = vec![];
-        let mut charstrings = vec![];
+        let mut char_sets = vec![];
+        let mut char_strings = vec![];
         let mut private_dictionaries = vec![];
         let mut local_subroutines = vec![];
         for (i, top) in top_dictionaries.iter().enumerate() {
@@ -68,18 +74,18 @@ impl Value for FontSet {
                 _ => unimplemented!(),
             });
 
-            charstrings.push({
-                try!(tape.jump(start + get_single!(top, Charstrings) as u64));
-                try!(Charstrings::read(tape, get_single!(top, CharstringType)))
+            char_strings.push({
+                try!(tape.jump(start + get_single!(top, CharStrings) as u64));
+                try!(CharStrings::read(tape, get_single!(top, CharStringType)))
             });
 
-            charsets.push(match get_single!(top, Charset) {
-                0 => Charset::ISOAdobe,
-                1 => Charset::Expert,
-                2 => Charset::ExpertSubset,
+            char_sets.push(match get_single!(top, CharSet) {
+                0 => CharSet::ISOAdobe,
+                1 => CharSet::Expert,
+                2 => CharSet::ExpertSubset,
                 offset => {
                     try!(tape.jump(start + offset as u64));
-                    try!(Charset::read(tape, charstrings[i].len()))
+                    try!(CharSet::read(tape, char_strings[i].len()))
                 },
             });
 
@@ -101,20 +107,14 @@ impl Value for FontSet {
         Ok(FontSet {
             header: header,
             names: names,
-            top_dictionaries: top_dictionaries,
             strings: strings,
-            global_subroutines: global_subroutines,
             encodings: encodings,
-            charsets: charsets,
-            charstrings: charstrings,
+            char_sets: char_sets,
+            char_strings: char_strings,
+            top_dictionaries: top_dictionaries,
             private_dictionaries: private_dictionaries,
+            global_subroutines: global_subroutines,
             local_subroutines: local_subroutines,
         })
     }
 }
-
-mod compound;
-mod primitive;
-
-pub use self::compound::*;
-pub use self::primitive::*;
